<?php

/**
    Tool for collaborative workshops.
    Copyright (C) 2016  Albert-Ludwigs-Universität Freiburg

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

class Workshop {
    protected $table;
    protected $db;

    function __construct($table) {
        $this->table = $table;
        try {
            $this->db = new PDO(DB_DSN, DB_USER, DB_PASS);
        } catch (PDOException $e) {
            die("<pre>Database connection failed:\n " . $e->getMessage() . "</pre>");
        }
    }

    public function writeField($field, $value) {
        $statement = $this->db->prepare("INSERT INTO `".DB_TABLE."` (`Table`, `Field`, `Value`) VALUES(?, ?, ?)");
        return $statement->execute(array($this->table, $field, $value));
    }

    public function getField($field) {
        $statement = $this->db->prepare("SELECT * FROM `".DB_TABLE."` WHERE `Table`=? AND `Field`=? ORDER BY `Time` DESC LIMIT 1");
        $statement->execute(array($this->table, $field));
        $row = $statement->fetch(PDO::FETCH_ASSOC);
        if (empty($row)) {
            return '';
        }
        return $row['Value'];
    }

    public function getOwnTable() {
        global $TABLES;
        return array('id'=>$this->table, 'name'=>$TABLES[$this->table]);
    }

    public function getOtherTables() {
        global $TABLES;
        $tables = array();
        foreach ($TABLES as $id => $name) {
            if ($id == $this->table) {
                continue;
            }
            $tables[$id] = array(
                'name' => $name,
                'sync' => $this->calculateSyncId($id),
            );
        }
        return $tables;
    }
    // Self   : 1(2) 2(3) 3(4) | 1(1) 2(3) 3(4) | 1(1) 2(2) 3(4) | 1(1) 2(2) 3(3)
    // Others : 1(2) 1(3) 1(4) | 1(2) 2(3) 2(4) | 2(1) 2(2) 3(4) | 3(1) 3(2) 3(3)
    private function calculateSyncId($otherTable) {
        $val = $this->table;
        if ($this->table == 0) {
            return 1;
        }
        if ($this->table == 1) {
            if ($otherTable == 0) return 1;
            return 2;
        }
        if ($this->table == 2) {
            if ($otherTable == 3) return 3;
            return 2;
        }
        if ($this->table == 3) {
            return 3;
        }
    }
}
